@@ -10,7 +10,7 @@ The Eclipse Public License is available at
 and the Eclipse Distribution License is available at
   http://www.eclipse.org/org/documents/edl-v10.php.
  
-SPDX-License-Identifier: EPL-2.0 OR EDL-1.0
+SPDX-License-Identifier: EPL-2.0 OR BSD-3-Clause
 
 Contributors:
    Roger Light - initial implementation and documentation.
@@ -18,6 +18,7 @@ Contributors:
 
 #include "config.h"
 
+#include <ctype.h>
 #include <errno.h>
 #include <openssl/evp.h>
 #include <openssl/rand.h>
@@ -51,7 +52,7 @@ Contributors:
 #  include <sys/stat.h>
 #endif
 
-#define MAX_BUFFER_LEN 65536
+#define MAX_BUFFER_LEN 65500
 #define SALT_LEN 12
 
 #include "misc_mosq.h"
@@ -106,7 +107,7 @@ static FILE *mpw_tmpfile(void)
 #endif
 
 
-void print_usage(void)
+static void print_usage(void)
 {
 	printf("mosquitto_passwd is a tool for managing password files for mosquitto.\n\n");
 	printf("Usage: mosquitto_passwd [-H sha512 | -H sha512-pbkdf2] [-c | -D] passwordfile username\n");
@@ -121,7 +122,7 @@ void print_usage(void)
 	printf("\nSee https://mosquitto.org/ for more information.\n\n");
 }
 
-int output_new_password(FILE *fptr, const char *username, const char *password, int iterations)
+static int output_new_password(FILE *fptr, const char *username, const char *password, int iterations)
 {
 	int rc;
 	char *salt64 = NULL, *hash64 = NULL;
@@ -240,6 +241,10 @@ static int pwfile_iterate(FILE *fptr, FILE *ftmp,
  * ====================================================================== */
 static int delete_pwuser_cb(FILE *fptr, FILE *ftmp, const char *username, const char *password, const char *line, struct cb_helper *helper)
 {
+	UNUSED(fptr);
+	UNUSED(password);
+	UNUSED(line);
+
 	if(strcmp(username, helper->username)){
 		/* If this isn't the username to delete, write it to the new file */
 		fprintf(ftmp, "%s", line);
@@ -250,7 +255,7 @@ static int delete_pwuser_cb(FILE *fptr, FILE *ftmp, const char *username, const
 	return 0;
 }
 
-int delete_pwuser(FILE *fptr, FILE *ftmp, const char *username)
+static int delete_pwuser(FILE *fptr, FILE *ftmp, const char *username)
 {
 	struct cb_helper helper;
 	int rc;
@@ -273,6 +278,9 @@ int delete_pwuser(FILE *fptr, FILE *ftmp, const char *username)
  * ====================================================================== */
 static int update_file_cb(FILE *fptr, FILE *ftmp, const char *username, const char *password, const char *line, struct cb_helper *helper)
 {
+	UNUSED(fptr);
+	UNUSED(line);
+
 	if(helper){
 		return output_new_password(ftmp, username, password, helper->iterations);
 	}else{
@@ -280,7 +288,7 @@ static int update_file_cb(FILE *fptr, FILE *ftmp, const char *username, const ch
 	}
 }
 
-int update_file(FILE *fptr, FILE *ftmp)
+static int update_file(FILE *fptr, FILE *ftmp)
 {
 	return pwfile_iterate(fptr, ftmp, update_file_cb, NULL);
 }
@@ -293,6 +301,9 @@ static int update_pwuser_cb(FILE *fptr, FILE *ftmp, const char *username, const
 {
 	int rc = 0;
 
+	UNUSED(fptr);
+	UNUSED(password);
+
 	if(strcmp(username, helper->username)){
 		/* If this isn't the matching user, then writing out the exiting line */
 		fprintf(ftmp, "%s", line);
@@ -304,7 +315,7 @@ static int update_pwuser_cb(FILE *fptr, FILE *ftmp, const char *username, const
 	return rc;
 }
 
-int update_pwuser(FILE *fptr, FILE *ftmp, const char *username, const char *password, int iterations)
+static int update_pwuser(FILE *fptr, FILE *ftmp, const char *username, const char *password, int iterations)
 {
 	struct cb_helper helper;
 	int rc;
@@ -323,7 +334,7 @@ int update_pwuser(FILE *fptr, FILE *ftmp, const char *username, const char *pass
 }
 
 
-int copy_contents(FILE *src, FILE *dest)
+static int copy_contents(FILE *src, FILE *dest)
 {
 	char buf[MAX_BUFFER_LEN];
 	size_t len;
@@ -350,7 +361,7 @@ int copy_contents(FILE *src, FILE *dest)
 	return 0;
 }
 
-int create_backup(const char *backup_file, FILE *fptr)
+static int create_backup(const char *backup_file, FILE *fptr)
 {
 	FILE *fbackup;
 
@@ -369,7 +380,7 @@ int create_backup(const char *backup_file, FILE *fptr)
 	return 0;
 }
 
-void handle_sigint(int signal)
+static void handle_sigint(int signal)
 {
 	get_password__reset_term();
 
@@ -378,6 +389,32 @@ void handle_sigint(int signal)
 	exit(0);
 }
 
+
+static bool is_username_valid(const char *username)
+{
+	size_t i;
+	size_t slen;
+
+	if(username){
+		slen = strlen(username);
+		if(slen > 65535){
+			fprintf(stderr, "Error: Username must be less than 65536 characters long.\n");
+			return false;
+		}
+		for(i=0; i<slen; i++){
+			if(iscntrl(username[i])){
+				fprintf(stderr, "Error: Username must not contain control characters.\n");
+				return false;
+			}
+		}
+		if(strchr(username, ':')){
+			fprintf(stderr, "Error: Username must not contain the ':' character.\n");
+			return false;
+		}
+	}
+	return true;
+}
+
 int main(int argc, char *argv[])
 {
 	char *password_file_tmp = NULL;
@@ -505,7 +542,7 @@ int main(int argc, char *argv[])
 	}else if(batch_mode == true && idx+3 == argc){
 		password_file_tmp = argv[idx];
 		username = argv[idx+1];
-		password_cmd = argv[idx+1];
+		password_cmd = argv[idx+2];
 	}else if(batch_mode == false && idx+2 == argc){
 		password_file_tmp = argv[idx];
 		username = argv[idx+1];
@@ -514,15 +551,8 @@ int main(int argc, char *argv[])
 		return 1;
 	}
 
-	if(username){
-		if(strlen(username) > 65535){
-			fprintf(stderr, "Error: Username must be less than 65536 characters long.\n");
-			return 1;
-		}
-		if(strchr(username, ':')){
-			fprintf(stderr, "Error: Username must not contain the ':' character.\n");
-			return 1;
-		}
+	if(!is_username_valid(username)){
+		return 1;
 	}
 	if(password_cmd && strlen(password_cmd) > 65535){
 		fprintf(stderr, "Error: Password must be less than 65536 characters long.\n");
