@@ -10,7 +10,7 @@ The Eclipse Public License is available at
 and the Eclipse Distribution License is available at
   http://www.eclipse.org/org/documents/edl-v10.php.
  
-SPDX-License-Identifier: EPL-2.0 OR EDL-1.0
+SPDX-License-Identifier: EPL-2.0 OR BSD-3-Clause
 
 Contributors:
    Roger Light - initial implementation and documentation.
@@ -125,7 +125,7 @@ int load_file(const char *filename)
 		return 1;
 	}
 	pos = 0;
-	while(pos < cfg.msglen){
+	while(pos < (size_t)cfg.msglen){
 		rlen = fread(&(cfg.message[pos]), sizeof(char), (size_t )cfg.msglen-pos, fptr);
 		pos += rlen;
 	}
