@@ -33,6 +33,15 @@
 #if defined(_MSC_VER) && _MSC_VER < 1900
 #  define snprintf sprintf_s
 #  define EPROTO ECONNABORTED
+#  ifndef ECONNABORTED
+#    define ECONNABORTED WSAECONNABORTED
+#  endif
+#  ifndef ENOTCONN
+#    define ENOTCONN WSAENOTCONN
+#  endif
+#  ifndef ECONNREFUSED
+#    define ECONNREFUSED WSAECONNREFUSED
+#  endif
 #endif
 
 #ifdef WIN32
@@ -74,7 +83,7 @@
 #endif
 
 #ifdef WITH_CJSON
-#  include <cJSON.h>
+#  include <cjson/cJSON.h>
 #  define CJSON_VERSION_FULL (CJSON_VERSION_MAJOR*1000000+CJSON_VERSION_MINOR*1000+CJSON_VERSION_PATCH)
 #endif
 
