@@ -106,7 +106,7 @@ int handle__connack(struct mosquitto *mosq)
 	mosquitto_property_read_int32(properties, MQTT_PROP_MAXIMUM_PACKET_SIZE, &mosq->maximum_packet_size, false);
 
 	mosq->msgs_out.inflight_quota = mosq->msgs_out.inflight_maximum;
-	message__reconnect_reset(mosq);
+	message__reconnect_reset(mosq, true);
 
 	connack_callback(mosq, reason_code, connect_flags, properties);
 	mosquitto_property_free_all(&properties);
