@@ -20,6 +20,10 @@ Contributors:
 
 #include "mosquitto.h"
 
-int log__printf(struct mosquitto *mosq, unsigned int priority, const char *fmt, ...);
+#ifndef __GNUC__
+#define __attribute__(attrib)
+#endif
+
+int log__printf(struct mosquitto *mosq, unsigned int level, const char *fmt, ...) __attribute__((format(printf, 3, 4)));
 
 #endif
