@@ -22,8 +22,10 @@ Contributors:
 #include <stdio.h>
 #include <sys/types.h>
 
-#if defined(WITH_MEMORY_TRACKING) && defined(WITH_BROKER) && defined(__GLIBC__)
-#define REAL_WITH_MEMORY_TRACKING
+#if defined(WITH_MEMORY_TRACKING) && defined(WITH_BROKER)
+#  if defined(__APPLE__) || defined(__FreeBSD__) || defined(__GLIBC__)
+#    define REAL_WITH_MEMORY_TRACKING
+#  endif
 #endif
 
 void *mosquitto__calloc(size_t nmemb, size_t size);
