@@ -122,6 +122,7 @@ void packet__cleanup_all_no_locks(struct mosquitto *mosq)
 		packet__cleanup(packet);
 		mosquitto__free(packet);
 	}
+	mosq->out_packet_count = 0;
 
 	packet__cleanup(&mosq->in_packet);
 }
@@ -157,6 +158,7 @@ int packet__queue(struct mosquitto *mosq, struct mosquitto__packet *packet)
 		mosq->out_packet = packet;
 	}
 	mosq->out_packet_last = packet;
+	mosq->out_packet_count++;
 	pthread_mutex_unlock(&mosq->out_packet_mutex);
 #ifdef WITH_BROKER
 #  ifdef WITH_WEBSOCKETS
@@ -223,6 +225,7 @@ int packet__write(struct mosquitto *mosq)
 		if(!mosq->out_packet){
 			mosq->out_packet_last = NULL;
 		}
+		mosq->out_packet_count--;
 	}
 	pthread_mutex_unlock(&mosq->out_packet_mutex);
 
@@ -312,6 +315,7 @@ int packet__write(struct mosquitto *mosq)
 			if(!mosq->out_packet){
 				mosq->out_packet_last = NULL;
 			}
+			mosq->out_packet_count--;
 		}
 		pthread_mutex_unlock(&mosq->out_packet_mutex);
 
@@ -320,15 +324,17 @@ int packet__write(struct mosquitto *mosq)
 
 #ifdef WITH_BROKER
 		mosq->next_msg_out = db.now_s + mosq->keepalive;
-		if(mosq->current_out_packet == NULL){
-			mux__remove_out(mosq);
-		}
 #else
 		pthread_mutex_lock(&mosq->msgtime_mutex);
 		mosq->next_msg_out = mosquitto_time() + mosq->keepalive;
 		pthread_mutex_unlock(&mosq->msgtime_mutex);
 #endif
 	}
+#ifdef WITH_BROKER
+	if (mosq->current_out_packet == NULL) {
+		mux__remove_out(mosq);
+	}
+#endif
 	pthread_mutex_unlock(&mosq->current_out_packet_mutex);
 	return MOSQ_ERR_SUCCESS;
 }
@@ -456,7 +462,7 @@ int packet__read(struct mosquitto *mosq)
 			return MOSQ_ERR_OVERSIZE_PACKET;
 		}
 #else
-		// FIXME - client case for incoming message received from broker too large
+		/* FIXME - client case for incoming message received from broker too large */
 #endif
 		if(mosq->in_packet.remaining_length > 0){
 			mosq->in_packet.payload = mosquitto__malloc(mosq->in_packet.remaining_length*sizeof(uint8_t));
