@@ -34,6 +34,7 @@ Contributors:
 #include <dlt/dlt.h>
 #endif
 
+#include "logging_mosq.h"
 #include "mosquitto_broker_internal.h"
 #include "memory_mosq.h"
 #include "misc_mosq.h"
@@ -186,7 +187,7 @@ DltLogLevelType get_dlt_level(unsigned int priority)
 }
 #endif
 
-int log__vprintf(unsigned int priority, const char *fmt, va_list va)
+static int log__vprintf(unsigned int priority, const char *fmt, va_list va)
 {
 	const char *topic;
 	int syslog_priority;
