@@ -181,9 +181,9 @@ void plugin__handle_tick(void)
 	struct mosquitto__callback *cb_base;
 	struct mosquitto__security_options *opts;
 
-	// FIXME - set now_s and now_ns to avoid need for multiple time lookups
+	/* FIXME - set now_s and now_ns to avoid need for multiple time lookups */
 	if(db.config->per_listener_settings){
-		// FIXME - iterate over all listeners
+		/* FIXME - iterate over all listeners */
 	}else{
 		opts = &db.config->security_options;
 		memset(&event_data, 0, sizeof(event_data));
@@ -274,7 +274,9 @@ int mosquitto_callback_unregister(
 	struct mosquitto__callback **cb_base = NULL;
 	struct mosquitto__security_options *security_options;
 
-	if(cb_func == NULL) return MOSQ_ERR_INVAL;
+	if(identifier == NULL || cb_func == NULL){
+		return MOSQ_ERR_INVAL;
+	}
 
 	if(identifier->listener == NULL){
 		security_options = &db.config->security_options;
