@@ -125,7 +125,6 @@ static int callback_mqtt(
 {
 	struct mosquitto *mosq = NULL;
 	struct mosquitto__packet *packet;
-	size_t txlen;
 	int count;
 	unsigned int ucount;
 	const struct lws_protocols *p;
@@ -218,6 +217,7 @@ static int callback_mqtt(
 				if(!mosq->out_packet){
 					mosq->out_packet_last = NULL;
 				}
+				mosq->out_packet_count--;
 			}
 
 			while(mosq->current_out_packet && !lws_send_pipe_choked(mosq->wsi)){
@@ -233,12 +233,7 @@ static int callback_mqtt(
 					memmove(&packet->payload[LWS_PRE], packet->payload, packet->packet_length);
 					packet->pos += LWS_PRE;
 				}
-				if(packet->to_process > WS_TX_BUF_SIZE){
-					txlen = WS_TX_BUF_SIZE;
-				}else{
-					txlen = packet->to_process;
-				}
-				count = lws_write(wsi, &packet->payload[packet->pos], txlen, LWS_WRITE_BINARY);
+				count = lws_write(wsi, &packet->payload[packet->pos], packet->to_process, LWS_WRITE_BINARY);
 				if(count < 0){
 					if (mosq->state == mosq_cs_disconnect_ws
 							|| mosq->state == mosq_cs_disconnecting
@@ -278,6 +273,7 @@ static int callback_mqtt(
 					if(!mosq->out_packet){
 						mosq->out_packet_last = NULL;
 					}
+					mosq->out_packet_count--;
 				}
 
 				packet__cleanup(packet);
@@ -660,6 +656,7 @@ static int callback_http(
 static void log_wrap(int level, const char *line)
 {
 	char *l = (char *)line;
+	UNUSED(level);
 	l[strlen(line)-1] = '\0'; /* Remove \n */
 	log__printf(NULL, MOSQ_LOG_WEBSOCKETS, "%s", l);
 }
