@@ -17,6 +17,8 @@ try:
     sock.close()
     rc = 0
 
+except mosq_test.TestError:
+    pass
 finally:
     broker.terminate()
     broker.wait()
