@@ -23,6 +23,8 @@ try:
     rc = 0
 
     sock.close()
+except mosq_test.TestError:
+    pass
 finally:
     broker.terminate()
     broker.wait()
