@@ -4,7 +4,7 @@
 
 from mosq_test_helper import *
 
-def write_config(filename, port1, port2, port3):
+def write_config(filename, port1, port2, port3, protocol_version):
     with open(filename, 'w') as f:
         f.write("per_listener_settings true\n")
         f.write("port %d\n" % (port2))
@@ -20,34 +20,21 @@ def write_config(filename, port1, port2, port3):
         f.write("topic clients/total in 0 test/mosquitto/org $SYS/broker/\n")
         f.write("notifications false\n")
         f.write("restart_timeout 5\n")
-
-(port1, port2, port3) = mosq_test.get_port(3)
-conf_file = os.path.basename(__file__).replace('.py', '.conf')
-write_config(conf_file, port1, port2, port3)
-
-rc = 1
-keepalive = 60
-client_id = socket.gethostname()+".bridge_sample"
-connect_packet = mosq_test.gen_connect(client_id, keepalive=keepalive, clean_session=False, proto_ver=128+4)
-connack_packet = mosq_test.gen_connack(rc=0)
-
-client_connect_packet = mosq_test.gen_connect("pub-test", keepalive=keepalive)
-client_connack_packet = mosq_test.gen_connack(rc=0)
-
-ssock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-ssock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
-ssock.settimeout(4)
-ssock.bind(('', port1))
-ssock.listen(5)
-
-broker = mosq_test.start_broker(filename=os.path.basename(__file__), port=port2, use_conf=True)
+        f.write("bridge_protocol_version %s\n" % (protocol_version))
 
 
-def test(bridge, sock):
+def inner_test(bridge, sock, proto_ver):
+    global connect_packet, connack_packet
+
     if not mosq_test.expect_packet(bridge, "connect", connect_packet):
         return 1
     bridge.send(connack_packet)
 
+    if proto_ver == 5:
+        opts = mqtt5_opts.MQTT_SUB_OPT_NO_LOCAL | mqtt5_opts.MQTT_SUB_OPT_RETAIN_AS_PUBLISHED
+    else:
+        opts = 0
+
     mid = 0
     patterns = [
         "remote/topic/#",
@@ -58,15 +45,15 @@ def test(bridge, sock):
     ]
     for pattern in ("remote/topic/#", "remote2/topic/prefix/#", "remote3/topic/+/value"):
         mid += 1
-        subscribe_packet = mosq_test.gen_subscribe(mid, pattern, 0)
-        suback_packet = mosq_test.gen_suback(mid, 0)
+        subscribe_packet = mosq_test.gen_subscribe(mid, pattern, 0 | opts, proto_ver=proto_ver)
+        suback_packet = mosq_test.gen_suback(mid, 0, proto_ver=proto_ver)
         if not mosq_test.expect_packet(bridge, "subscribe", subscribe_packet):
             return 1
         bridge.send(suback_packet)
 
     mid += 1
-    subscribe_packet = mosq_test.gen_subscribe(mid, "#", 0)
-    suback_packet = mosq_test.gen_suback(mid, 0)
+    subscribe_packet = mosq_test.gen_subscribe(mid, "#", 0 | opts, proto_ver=proto_ver)
+    suback_packet = mosq_test.gen_suback(mid, 0, proto_ver=proto_ver)
     sock.send(subscribe_packet)
     if not mosq_test.expect_packet(sock, "suback", suback_packet):
         return 1
@@ -86,11 +73,9 @@ def test(bridge, sock):
     for (local_topic, remote_topic) in cases:
         mid += 1
         remote_publish_packet = mosq_test.gen_publish(
-            remote_topic, qos=0, mid=mid, payload=''
-        )
+            remote_topic, qos=0, mid=mid, payload='', proto_ver=proto_ver)
         local_publish_packet = mosq_test.gen_publish(
-            local_topic, qos=0, mid=mid, payload=''
-        )
+            local_topic, qos=0, mid=mid, payload='', proto_ver=proto_ver)
 
         bridge.send(remote_publish_packet)
         match = mosq_test.expect_packet(sock, "publish", local_publish_packet)
@@ -101,31 +86,70 @@ def test(bridge, sock):
             return 1
     return 0
 
-try:
-    (bridge, address) = ssock.accept()
-    bridge.settimeout(2)
 
-    sock = mosq_test.do_client_connect(
-        client_connect_packet, client_connack_packet,
-        port=port2,
-    )
+def do_test(proto_ver):
+    global connect_packet, connack_packet
 
-    rc = test(bridge, sock)
+    if proto_ver == 4:
+        bridge_protocol = "mqttv311"
+        proto_ver_connect = 128+4
+    else:
+        bridge_protocol = "mqttv50"
+        proto_ver_connect = 5
+
+    (port1, port2, port3) = mosq_test.get_port(3)
+    conf_file = os.path.basename(__file__).replace('.py', '.conf')
+    write_config(conf_file, port1, port2, port3, bridge_protocol)
+
+    rc = 1
+    keepalive = 60
+    client_id = socket.gethostname()+".bridge_sample"
+    connect_packet = mosq_test.gen_connect(client_id, keepalive=keepalive, clean_session=False, proto_ver=proto_ver_connect)
+    connack_packet = mosq_test.gen_connack(rc=0, proto_ver=proto_ver)
+
+    client_connect_packet = mosq_test.gen_connect("pub-test", keepalive=keepalive, proto_ver=proto_ver)
+    client_connack_packet = mosq_test.gen_connack(rc=0, proto_ver=proto_ver)
+
+    ssock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+    ssock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
+    ssock.settimeout(4)
+    ssock.bind(('', port1))
+    ssock.listen(5)
+
+    broker = mosq_test.start_broker(filename=os.path.basename(__file__), port=port2, use_conf=True)
 
-    sock.close()
-    bridge.close()
-finally:
-    os.remove(conf_file)
     try:
+        (bridge, address) = ssock.accept()
+        bridge.settimeout(2)
+
+        sock = mosq_test.do_client_connect(
+            client_connect_packet, client_connack_packet,
+            port=port2,
+        )
+
+        rc = inner_test(bridge, sock, proto_ver)
+
+        sock.close()
         bridge.close()
-    except NameError:
+    except mosq_test.TestError:
         pass
+    finally:
+        os.remove(conf_file)
+        try:
+            bridge.close()
+        except NameError:
+            pass
 
-    broker.terminate()
-    broker.wait()
-    (stdo, stde) = broker.communicate()
-    if rc:
-        print(stde.decode('utf-8'))
-    ssock.close()
+        broker.terminate()
+        broker.wait()
+        (stdo, stde) = broker.communicate()
+        ssock.close()
+        if rc:
+            print(stde.decode('utf-8'))
+            exit(rc)
 
-exit(rc)
+
+do_test(proto_ver=4)
+do_test(proto_ver=5)
+
+exit(0)
