@@ -5,6 +5,7 @@ from mosq_test_helper import *
 def write_config(filename, port1, port2):
     with open(filename, 'w') as f:
         f.write("port %d\n" % (port2))
+        f.write("allow_anonymous true\n")
         f.write("\n")
         f.write("connection bridge_test\n")
         f.write("address 127.0.0.1:%d\n" % (port1))
@@ -44,20 +45,22 @@ try:
     (bridge, address) = ssock.accept()
     bridge.settimeout(20)
 
-    if mosq_test.expect_packet(bridge, "connect", connect_packet):
-        bridge.send(connack_packet)
+    mosq_test.expect_packet(bridge, "connect", connect_packet)
+    bridge.send(connack_packet)
 
-        if mosq_test.expect_packet(bridge, "subscribe", subscribe_packet):
-            bridge.send(suback_packet)
+    mosq_test.expect_packet(bridge, "subscribe", subscribe_packet)
+    bridge.send(suback_packet)
 
-            pub = subprocess.Popen(['./08-ssl-bridge-helper.py', str(port2)], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-            pub.wait()
-            (stdo, stde) = pub.communicate()
+    pub = subprocess.Popen(['./08-ssl-bridge-helper.py', str(port2)], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+    pub.wait()
+    (stdo, stde) = pub.communicate()
 
-            if mosq_test.expect_packet(bridge, "publish", publish_packet):
-                rc = 0
+    mosq_test.expect_packet(bridge, "publish", publish_packet)
+    rc = 0
 
     bridge.close()
+except mosq_test.TestError:
+    pass
 finally:
     os.remove(conf_file)
     try:
