@@ -42,6 +42,8 @@ try:
         else:
             broker.terminate()
             raise ValueError(err.errno)
+except mosq_test.TestError:
+    pass
 finally:
     os.remove(conf_file)
     time.sleep(0.5)
