@@ -11,7 +11,9 @@ if sys.version < '2.7':
 def write_config(filename, port1, port2):
     with open(filename, 'w') as f:
         f.write("port %d\n" % (port2))
+        f.write("allow_anonymous true\n")
         f.write("listener %d\n" % (port1))
+        f.write("allow_anonymous true\n")
         f.write("cafile ../ssl/all-ca.crt\n")
         f.write("certfile ../ssl/server.crt\n")
         f.write("keyfile ../ssl/server.key\n")
@@ -39,6 +41,8 @@ try:
     rc = 0
 
     ssock.close()
+except mosq_test.TestError:
+    pass
 finally:
     os.remove(conf_file)
     broker.terminate()
