@@ -36,6 +36,8 @@ try:
 except ssl.SSLError as err:
     if err.errno == 1:
         rc = 0
+except mosq_test.TestError:
+    pass
 finally:
     os.remove(conf_file)
     ssock.close()
