@@ -41,6 +41,8 @@ try:
     rc = 0
 
     ssock.close()
+except mosq_test.TestError:
+    pass
 finally:
     os.remove(conf_file)
     time.sleep(2)
