@@ -73,6 +73,8 @@ def do_test(suffix):
         sock.close()
 
         rc = 0
+    except mosq_test.TestError:
+        pass
     finally:
         os.remove(conf_file)
         broker.terminate()
