@@ -8,9 +8,9 @@
 static void byte_prop_read_helper(
 		int command,
 		uint8_t *payload,
-		int remaining_length,
+		uint32_t remaining_length,
 		int rc_expected,
-		int identifier,
+		uint8_t identifier,
 		uint8_t value_expected)
 {
 	struct mosquitto__packet packet;
@@ -34,7 +34,7 @@ static void byte_prop_read_helper(
 	CU_ASSERT_PTR_EQUAL(properties, NULL);
 }
 
-static void duplicate_byte_helper(int command, int identifier)
+static void duplicate_byte_helper(int command, uint8_t identifier)
 {
 	uint8_t payload[20];
 
@@ -48,7 +48,7 @@ static void duplicate_byte_helper(int command, int identifier)
 	byte_prop_read_helper(command, payload, 5, MOSQ_ERR_DUPLICATE_PROPERTY, identifier, 1);
 }
 
-static void bad_byte_helper(int command, int identifier)
+static void bad_byte_helper(int command, uint8_t identifier)
 {
 	uint8_t payload[20];
 
@@ -64,9 +64,9 @@ static void bad_byte_helper(int command, int identifier)
 static void int32_prop_read_helper(
 		int command,
 		uint8_t *payload,
-		int remaining_length,
+		uint32_t remaining_length,
 		int rc_expected,
-		int identifier,
+		uint8_t identifier,
 		uint32_t value_expected)
 {
 	struct mosquitto__packet packet;
@@ -90,7 +90,7 @@ static void int32_prop_read_helper(
 	CU_ASSERT_PTR_EQUAL(properties, NULL);
 }
 
-static void duplicate_int32_helper(int command, int identifier)
+static void duplicate_int32_helper(int command, uint8_t identifier)
 {
 	uint8_t payload[20];
 
@@ -114,9 +114,9 @@ static void duplicate_int32_helper(int command, int identifier)
 static void int16_prop_read_helper(
 		int command,
 		uint8_t *payload,
-		int remaining_length,
+		uint32_t remaining_length,
 		int rc_expected,
-		int identifier,
+		uint8_t identifier,
 		uint16_t value_expected)
 {
 	struct mosquitto__packet packet;
@@ -140,7 +140,7 @@ static void int16_prop_read_helper(
 	CU_ASSERT_PTR_EQUAL(properties, NULL);
 }
 
-static void duplicate_int16_helper(int command, int identifier)
+static void duplicate_int16_helper(int command, uint8_t identifier)
 {
 	uint8_t payload[20];
 
@@ -159,9 +159,9 @@ static void duplicate_int16_helper(int command, int identifier)
 static void string_prop_read_helper(
 		int command,
 		uint8_t *payload,
-		int remaining_length,
+		uint32_t remaining_length,
 		int rc_expected,
-		int identifier,
+		uint8_t identifier,
 		const char *value_expected)
 {
 	struct mosquitto__packet packet;
@@ -186,7 +186,7 @@ static void string_prop_read_helper(
 	CU_ASSERT_PTR_EQUAL(properties, NULL);
 }
 
-static void duplicate_string_helper(int command, int identifier)
+static void duplicate_string_helper(int command, uint8_t identifier)
 {
 	uint8_t payload[20];
 
@@ -204,7 +204,7 @@ static void duplicate_string_helper(int command, int identifier)
 	string_prop_read_helper(command, payload, 9, MOSQ_ERR_DUPLICATE_PROPERTY, identifier, "");
 }
 
-static void bad_string_helper(int identifier)
+static void bad_string_helper(uint8_t identifier)
 {
 	uint8_t payload[20];
 
@@ -223,9 +223,9 @@ static void bad_string_helper(int identifier)
 static void binary_prop_read_helper(
 		int command,
 		uint8_t *payload,
-		int remaining_length,
+		uint32_t remaining_length,
 		int rc_expected,
-		int identifier,
+		uint8_t identifier,
 		const uint8_t *value_expected,
 		int len_expected)
 {
@@ -243,7 +243,7 @@ static void binary_prop_read_helper(
 	if(properties){
 		CU_ASSERT_EQUAL(properties->identifier, identifier);
 		CU_ASSERT_EQUAL(properties->value.bin.len, len_expected);
-		CU_ASSERT_EQUAL(memcmp(properties->value.bin.v, value_expected, len_expected), 0);
+		CU_ASSERT_EQUAL(memcmp(properties->value.bin.v, value_expected, (size_t)len_expected), 0);
 		CU_ASSERT_PTR_EQUAL(properties->next, NULL);
 		CU_ASSERT_EQUAL(property__get_length_all(properties), 1+2+len_expected);
 		mosquitto_property_free_all(&properties);
@@ -251,7 +251,7 @@ static void binary_prop_read_helper(
 	CU_ASSERT_PTR_EQUAL(properties, NULL);
 }
 
-static void duplicate_binary_helper(int command, int identifier)
+static void duplicate_binary_helper(int command, uint8_t identifier)
 {
 	uint8_t payload[20];
 
@@ -271,9 +271,9 @@ static void duplicate_binary_helper(int command, int identifier)
 
 static void string_pair_prop_read_helper(
 		uint8_t *payload,
-		int remaining_length,
+		uint32_t remaining_length,
 		int rc_expected,
-		int identifier,
+		uint8_t identifier,
 		const char *name_expected,
 		const char *value_expected,
 		bool expect_multiple)
@@ -308,9 +308,9 @@ static void string_pair_prop_read_helper(
 
 static void varint_prop_read_helper(
 		uint8_t *payload,
-		int remaining_length,
+		uint32_t remaining_length,
 		int rc_expected,
-		int identifier,
+		uint8_t identifier,
 		uint32_t value_expected)
 {
 	struct mosquitto__packet packet;
